@@ -6,7 +6,6 @@ from typing import Dict
 from typing import List
 from typing import Optional
 from typing import Tuple
-from requests.exceptions import ConnectionError
 
 from .connection import CloudflareScraper
 from .connection import Response
@@ -17,6 +16,7 @@ from .connection import join_url
 from .connection import make_session
 from .journal import Journal
 from .parse import BeautifulSoup
+from .parse import check_page
 from .parse import parse_page
 from .submission import Submission
 from .submission import SubmissionPartial
@@ -95,7 +95,7 @@ class FAAPI:
 
         page_parsed: Optional[BeautifulSoup] = self.get_parse(join_url("user", user))
 
-        if page_parsed is None:
+        if not check_page(page_parsed):
             return "", "", None
 
         username_div = page_parsed.find("div", class_="username")
@@ -114,7 +114,7 @@ class FAAPI:
 
         page_parsed = self.get_parse(join_url("gallery", user, page))
 
-        if page_parsed is None or page_parsed.title.text.lower().startswith("account disabled"):
+        if not check_page(page_parsed):
             return [], 0
 
         subs = page_parsed.findAll("figure")
@@ -127,7 +127,7 @@ class FAAPI:
 
         page_parsed = self.get_parse(join_url("scraps", user, page))
 
-        if page_parsed is None or page_parsed.title.text.lower().startswith("account disabled"):
+        if not check_page(page_parsed):
             return [], 0
 
         subs = page_parsed.findAll("figure")
@@ -140,7 +140,7 @@ class FAAPI:
 
         page_parsed = self.get_parse(join_url("favorites", user, page))
 
-        if page_parsed is None or page_parsed.title.text.lower().startswith("account disabled"):
+        if not check_page(page_parsed):
             return [], ""
 
         subs = page_parsed.findAll("figure")
@@ -155,6 +155,9 @@ class FAAPI:
         assert isinstance(page, int)
 
         page_parsed = self.get_parse(join_url("journals", user, page))
+        if not check_page(page_parsed):
+            return [], 0
+
         username = page_parsed.find("div", class_="username").find("span").text.strip()[1:]
 
         journals_tags = page_parsed.findAll("section")
@@ -170,7 +173,7 @@ class FAAPI:
 
         page_parsed = self.get_parse("search", q=q, page=page, **params)
 
-        if page_parsed is None:
+        if not check_page(page_parsed):
             return [], 0, 0, 0, 0
 
         subs = page_parsed.findAll("figure")
@@ -184,46 +187,74 @@ class FAAPI:
 
         return list(map(SubmissionPartial, subs)), page_next, a - 1, b - 1, tot
 
-    def user_exists(self, user: str) -> bool:
+    def user_exists(self, user: str) -> int:
+        """
+        0 okay
+        1 account disabled
+        2 system error
+        3 unknown error
+        4 request error
+        """
+
         assert isinstance(user, str)
 
         res = self.get(join_url("user", user))
 
         if not res.ok:
-            return False
-        elif not (title := parse_page(res.text).title.text):
-            return False
-        elif title.lower() == "system error":
-            return False
-        elif title.lower().startswith("account disabled"):
-            return False
+            return 4
+        elif (check := check_page(parse_page(res.text))) == 0:
+            return 0
+        elif check == 3:
+            return 1
+        elif check == 4:
+            return 2
         else:
-            return True
+            return 3
+
+    def sub_exists(self, sub_id: int) -> int:
+        """
+        0 okay
+        1 account disabled
+        2 system error
+        3 unknown error
+        4 request error
+        """
 
-    def sub_exists(self, sub_id: int) -> bool:
         assert isinstance(sub_id, int) and sub_id > 0
 
         res = self.get(join_url("view", sub_id))
 
         if not res.ok:
-            return False
-        elif not (title := parse_page(res.text).title.text):
-            return False
-        elif title.lower() == "system error":
-            return False
+            return 4
+        elif (check := check_page(parse_page(res.text))) == 0:
+            return 0
+        elif check == 3:
+            return 1
+        elif check == 4:
+            return 2
         else:
-            return True
+            return 3
+
+    def journal_exists(self, journal_id: int) -> int:
+        """
+        0 okay
+        1 account disabled
+        2 system error
+        3 unknown error
+        4 request error
+        """
 
-    def journal_exists(self, journal_id: int) -> bool:
         assert isinstance(journal_id, int) and journal_id > 0
 
         res = self.get(join_url("journal", journal_id))
 
         if not res.ok:
-            return False
-        elif not (title := parse_page(res.text).title.text):
-            return False
-        elif title.lower() == "system error":
-            return False
+            return 4
+        elif (check := check_page(parse_page(res.text))) == 0:
+            return 0
+        elif check == 3:
+            return 1
+        elif check == 4:
+            return 2
         else:
-            return True
+            return 3
