@@ -11,6 +11,30 @@ def parse_page(text: str) -> BeautifulSoup:
     return BeautifulSoup(text, "lxml")
 
 
+def check_page(page: BeautifulSoup) -> int:
+    """
+    0 if page is okay
+    1 if page is None
+    2 if page has no title
+    3 if page is from a disabled account
+    4 if page is a system error
+    5 if page has a notice-message (error)
+    """
+
+    if page is None:
+        return 1
+    elif not (title := page.title.text.lower()):
+        return 2
+    elif title.startswith("account disabled"):
+        return 3
+    elif title == "system error":
+        return 4
+    elif notice := page.find("section", class_="notice-message"):
+        return 3 if (p := notice.find("p")) and "deactivated" in p.text.lower() else 5
+
+    return 0
+
+
 def parse_journal_section(section_tag: Tag) -> Dict[str, Union[int, str]]:
     id_: int = int(section_tag.attrs["id"][4:])
     title: str = section_tag.find("h2").text.strip()
@@ -26,6 +50,8 @@ def parse_journal_section(section_tag: Tag) -> Dict[str, Union[int, str]]:
 
 
 def parse_journal_page(journal_page: BeautifulSoup) -> Dict[str, Union[int, str]]:
+    check_page(journal_page)
+
     tag_id: Tag = journal_page.find("meta", property="og:url")
     tag_title: Tag = journal_page.find("h2", class_="journal-title")
     tag_author: Tag = journal_page.find("a", class_="current")
@@ -66,8 +92,7 @@ def parse_submission_figure(figure_tag: Tag) -> Dict[str, Union[int, str]]:
 
 
 def parse_submission_page(sub_page: BeautifulSoup) -> Dict[str, Union[int, str, List[str]]]:
-    if sub_page.find("section", class_="notice-message"):
-        raise Exception("Error: notice-message section found")
+    check_page(sub_page)
 
     tag_id: Tag = sub_page.find("meta", property="og:url")
     tag_sub_info: Tag = sub_page.find("div", class_="submission-id-sub-container")
